==> zio-aws-iotfleetwise_2.13-5.20.17.2-sources.jar: zio/aws/iotfleetwise/model/FleetSummary.scala <==
package zio.aws.iotfleetwise.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.iotfleetwise.model.primitives.{
  Timestamp,
  Description,
  Arn,
  FleetId
}
import scala.jdk.CollectionConverters._
final case class FleetSummary(
    id: FleetId,
    arn: Arn,
    description: Optional[Description] = Optional.Absent,
    signalCatalogArn: Arn,
    creationTime: Timestamp,
    lastModificationTime: Optional[Timestamp] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iotfleetwise.model.FleetSummary = {
    import FleetSummary.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iotfleetwise.model.FleetSummary
      .builder()
      .id(FleetId.unwrap(id): java.lang.String)
      .arn(Arn.unwrap(arn): java.lang.String)
      .optionallyWith(
        description.map(value => Description.unwrap(value): java.lang.String)
      )(_.description)
      .signalCatalogArn(Arn.unwrap(signalCatalogArn): java.lang.String)
      .creationTime(Timestamp.unwrap(creationTime): Instant)
      .optionallyWith(
        lastModificationTime.map(value => Timestamp.unwrap(value): Instant)
      )(_.lastModificationTime)
      .build()
  }
  def asReadOnly: zio.aws.iotfleetwise.model.FleetSummary.ReadOnly =
    zio.aws.iotfleetwise.model.FleetSummary.wrap(buildAwsValue())
}
object FleetSummary {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iotfleetwise.model.FleetSummary
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iotfleetwise.model.FleetSummary =
      zio.aws.iotfleetwise.model.FleetSummary(
        id,
        arn,
        description.map(value => value),
        signalCatalogArn,
        creationTime,
        lastModificationTime.map(value => value)
      )
    def id: FleetId
    def arn: Arn
    def description: Optional[Description]
    def signalCatalogArn: Arn
    def creationTime: Timestamp
    def lastModificationTime: Optional[Timestamp]
    def getId: ZIO[Any, Nothing, FleetId] = ZIO.succeed(id)
    def getArn: ZIO[Any, Nothing, Arn] = ZIO.succeed(arn)
    def getDescription: ZIO[Any, AwsError, Description] =
      AwsError.unwrapOptionField("description", description)
    def getSignalCatalogArn: ZIO[Any, Nothing, Arn] =
      ZIO.succeed(signalCatalogArn)
    def getCreationTime: ZIO[Any, Nothing, Timestamp] =
      ZIO.succeed(creationTime)
    def getLastModificationTime: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("lastModificationTime", lastModificationTime)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iotfleetwise.model.FleetSummary
  ) extends zio.aws.iotfleetwise.model.FleetSummary.ReadOnly {
    override val id: FleetId =
      zio.aws.iotfleetwise.model.primitives.FleetId(impl.id())
    override val arn: Arn =
      zio.aws.iotfleetwise.model.primitives.Arn(impl.arn())
    override val description: Optional[Description] = zio.aws.core.internal
      .optionalFromNullable(impl.description())
      .map(value => zio.aws.iotfleetwise.model.primitives.Description(value))
    override val signalCatalogArn: Arn =
      zio.aws.iotfleetwise.model.primitives.Arn(impl.signalCatalogArn())
    override val creationTime: Timestamp =
      zio.aws.iotfleetwise.model.primitives.Timestamp(impl.creationTime())
    override val lastModificationTime: Optional[Timestamp] =
      zio.aws.core.internal
        .optionalFromNullable(impl.lastModificationTime())
        .map(value => zio.aws.iotfleetwise.model.primitives.Timestamp(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iotfleetwise.model.FleetSummary
  ): zio.aws.iotfleetwise.model.FleetSummary.ReadOnly = new Wrapper(impl)
}

==> zio-aws-iotfleetwise_3-7.21.15.9-sources.jar: zio/aws/iotfleetwise/model/FleetSummary.scala <==
package zio.aws.iotfleetwise.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.iotfleetwise.model.primitives.{
  Timestamp,
  Description,
  Arn,
  FleetId
}
import scala.jdk.CollectionConverters.*
final case class FleetSummary(
    id: FleetId,
    arn: Arn,
    description: Optional[Description] = Optional.Absent,
    signalCatalogArn: Arn,
    creationTime: Timestamp,
    lastModificationTime: Optional[Timestamp] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iotfleetwise.model.FleetSummary = {
    import FleetSummary.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iotfleetwise.model.FleetSummary
      .builder()
      .id(FleetId.unwrap(id): java.lang.String)
      .arn(Arn.unwrap(arn): java.lang.String)
      .optionallyWith(
        description.map(value => Description.unwrap(value): java.lang.String)
      )(_.description)
      .signalCatalogArn(Arn.unwrap(signalCatalogArn): java.lang.String)
      .creationTime(Timestamp.unwrap(creationTime): Instant)
      .optionallyWith(
        lastModificationTime.map(value => Timestamp.unwrap(value): Instant)
      )(_.lastModificationTime)
      .build()
  }
  def asReadOnly: zio.aws.iotfleetwise.model.FleetSummary.ReadOnly =
    zio.aws.iotfleetwise.model.FleetSummary.wrap(buildAwsValue())
}
object FleetSummary {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iotfleetwise.model.FleetSummary
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iotfleetwise.model.FleetSummary =
      zio.aws.iotfleetwise.model.FleetSummary(
        id,
        arn,
        description.map(value => value),
        signalCatalogArn,
        creationTime,
        lastModificationTime.map(value => value)
      )
    def id: FleetId
    def arn: Arn
    def description: Optional[Description]
    def signalCatalogArn: Arn
    def creationTime: Timestamp
    def lastModificationTime: Optional[Timestamp]
    def getId: ZIO[Any, Nothing, FleetId] = ZIO.succeed(id)
    def getArn: ZIO[Any, Nothing, Arn] = ZIO.succeed(arn)
    def getDescription: ZIO[Any, AwsError, Description] =
      AwsError.unwrapOptionField("description", description)
    def getSignalCatalogArn: ZIO[Any, Nothing, Arn] =
      ZIO.succeed(signalCatalogArn)
    def getCreationTime: ZIO[Any, Nothing, Timestamp] =
      ZIO.succeed(creationTime)
    def getLastModificationTime: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("lastModificationTime", lastModificationTime)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iotfleetwise.model.FleetSummary
  ) extends zio.aws.iotfleetwise.model.FleetSummary.ReadOnly {
    override val id: FleetId =
      zio.aws.iotfleetwise.model.primitives.FleetId(impl.id())
    override val arn: Arn =
      zio.aws.iotfleetwise.model.primitives.Arn(impl.arn())
    override val description: Optional[Description] = zio.aws.core.internal
      .optionalFromNullable(impl.description())
      .map(value => zio.aws.iotfleetwise.model.primitives.Description(value))
    override val signalCatalogArn: Arn =
      zio.aws.iotfleetwise.model.primitives.Arn(impl.signalCatalogArn())
    override val creationTime: Timestamp =
      zio.aws.iotfleetwise.model.primitives.Timestamp(impl.creationTime())
    override val lastModificationTime: Optional[Timestamp] =
      zio.aws.core.internal
        .optionalFromNullable(impl.lastModificationTime())
        .map(value => zio.aws.iotfleetwise.model.primitives.Timestamp(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iotfleetwise.model.FleetSummary
  ): zio.aws.iotfleetwise.model.FleetSummary.ReadOnly = new Wrapper(impl)
}
